@@ -81,27 +81,25 @@ extern crate log;
 #[allow(unused_imports, non_snake_case)]
 #[cfg_attr(rustfmt, rustfmt_skip)]
 mod feature_generated;
+mod feature_writer;
 mod file_reader;
+mod file_writer;
 mod geometry_reader;
 #[allow(unused_imports, non_snake_case)]
 #[cfg_attr(rustfmt, rustfmt_skip)]
 mod header_generated;
 #[cfg(feature = "http")]
-mod http_client;
-#[cfg(feature = "http")]
 mod http_reader;
-mod packed_r_tree;
+pub mod packed_r_tree;
 mod properties_reader;
 
 pub use feature_generated::*;
 pub use file_reader::*;
+pub use file_writer::*;
 pub use geometry_reader::*;
 pub use header_generated::*;
 #[cfg(feature = "http")]
-pub use http_client::*;
-#[cfg(feature = "http")]
 pub use http_reader::*;
-pub use packed_r_tree::*;
 pub use properties_reader::*;
 
 // Re-export used traits
@@ -109,7 +107,7 @@ pub use fallible_streaming_iterator::FallibleStreamingIterator;
 pub use geozero::{FeatureAccess, FeatureProperties, GeozeroGeometry};
 
 pub const VERSION: u8 = 3;
-const MAGIC_BYTES: [u8; 8] = [b'f', b'g', b'b', VERSION, b'f', b'g', b'b', 0];
+pub(crate) const MAGIC_BYTES: [u8; 8] = [b'f', b'g', b'b', VERSION, b'f', b'g', b'b', 0];
 
 const HEADER_MAX_BUFFER_SIZE: usize = 1048576 * 10;
 
